@@ -3,16 +3,27 @@
 # ==============================================================================
 setMethod( "imputed", signature( object = "mi.method" ),     
   function ( object, y ) {
-    y[is.na( y )] <- object$random
+    y[is.na( y )] <- object@random
     return( y )
   }
 )
-# ==============================================================================
-# extract imputed values for mi.mixed class object
-# ==============================================================================
-setMethod("imputed", signature(object = "mi.mixed"),     
+
+
+setMethod( "imputed", signature( object = "mi.categorical" ),     
   function ( object, y ) {
-    y[ is.na( y ) ] <- object$random
+    #y.level <- levels(y)
+    #y <- as.numeric(y)  
+    y[is.na( y )] <- object@random
+    return( y )
+  }
+)
+
+
+setMethod( "imputed", signature( object = "mi.polr" ),     
+  function ( object, y ) {
+    #y.level <- levels(y)
+    #y <- as.numeric(y)  
+    y[is.na( y )] <- object@random
     return( y )
   }
 )
